@@ -1,8 +1,7 @@
 from dataclasses import dataclass
 from enum import Enum
-from typing import Optional
 
-__all__ = ["ErrorLevel", "GeneratorError", "ParseError", "PropertyError", "ValidationError", "ParameterError"]
+__all__ = ["ErrorLevel", "GeneratorError", "ParameterError", "ParseError", "PropertyError"]
 
 from pydantic import BaseModel
 
@@ -18,7 +17,7 @@ class ErrorLevel(Enum):
 class GeneratorError:
     """Base data struct containing info on an error that occurred"""
 
-    detail: Optional[str] = None
+    detail: str | None = None
     level: ErrorLevel = ErrorLevel.ERROR
     header: str = "Unable to generate the client"
 
@@ -28,7 +27,7 @@ class ParseError(GeneratorError):
     """An error raised when there's a problem parsing an OpenAPI document"""
 
     level: ErrorLevel = ErrorLevel.WARNING
-    data: Optional[BaseModel] = None
+    data: BaseModel | None = None
     header: str = "Unable to parse this part of your OpenAPI document: "
 
 
@@ -44,7 +43,3 @@ class ParameterError(ParseError):
     """Error raised when there's a problem creating a Parameter."""
 
     header = "Problem creating a Parameter: "
-
-
-class ValidationError(Exception):
-    """Used internally to exit quickly from property parsing due to some internal exception."""
