@@ -1,13 +1,11 @@
-from typing import TYPE_CHECKING, Optional, Union
+from typing import TYPE_CHECKING
 
 from pydantic import BaseModel, ConfigDict
 
-from .reference import Reference
+from .reference import ReferenceOr
 
 if TYPE_CHECKING:  # pragma: no cover
     from .header import Header
-else:
-    Header = "Header"
 
 
 class Encoding(BaseModel):
@@ -18,12 +16,14 @@ class Encoding(BaseModel):
         - https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.0.3.md#encodingObject
     """
 
-    contentType: Optional[str] = None
-    headers: Optional[dict[str, Union[Header, Reference]]] = None
-    style: Optional[str] = None
+    contentType: str | None = None
+    headers: dict[str, ReferenceOr["Header"]] | None = None
+    style: str | None = None
     explode: bool = False
     allowReserved: bool = False
     model_config = ConfigDict(
+        # `Header` is an unresolvable forward reference, will rebuild in `__init__.py`:
+        defer_build=True,
         extra="allow",
         json_schema_extra={
             "examples": [
